<?php declare (strict_types = 1);

namespace EuKit\Base\ViewModels;

use EuKit\Base\Parts\Image;
use Infomaker\Everyware\NewsML\Objects\TeaserItem;
use Infomaker\Everyware\Support\GenericPropertyObject;
use Infomaker\Everyware\Support\Interfaces\PropertyObject;

/**
 * Class TeaserArticle
 * @package EuKit\Base
 */
class Teaser extends BaseObject
{
    public function __construct(PropertyObject $article)
    {
        $teaser = $article->getNewsMLTeaser();
        $propertyObject = new GenericPropertyObject();
        $propertyObject->fill([
            'uuid' => $article->getSingleValue('uuid'),
            'pubdate' => $article->getPubDate()->diffForHumans(),
            'pubdatetime' => $article->getPubDate(),
            'headline' => $article->getSingleValue('headline'),
            'leadin' => $article->getSingleValue('leadin'),
            'authors' => $article->authors,
            'permalink' => $article->getSingleValue('permalink'),
            'sectionName' => $article->getSingleValue('section'),
            'categoriesName' => $article->categories->first() ? $article->categories->first()->getFirstOfSingleValue('name') : '',
            'tagsName' => $article->tags->first() ? $article->tags->first()->getFirstOfSingleValue('name') : '',
            'relatedArticles' => $article->articles,
        ]);

        if ($teaser instanceof TeaserItem) {
            $propertyObject->fill($this->createTeaser($teaser));
        }

        parent::__construct($propertyObject);
    }

    private function createTeaser(TeaserItem $teaser): array
    {
        $image = $teaser->hasImage() ? new Image($teaser->getImage()) : null;

        $teaserData = array_replace($teaser->toArray(), [
            'image' => $image instanceof Image ? $image->getViewData() : null,
        ]);

        return array_filter($teaserData);
    }
}
